pub struct ChickenVariant {
pub key: Identifier,
pub asset_id: Identifier,
pub baby_asset_id: Identifier,
pub model: ChickenModelType,
pub spawn_conditions: &'static [SpawnConditionEntry],
}Expand description
Represents a full chicken variant definition from a data pack JSON file.
Fields
key: Identifierasset_id: Identifierbaby_asset_id: Identifiermodel: ChickenModelTypespawn_conditions: &'static [SpawnConditionEntry]Trait Implementations
Sourceimpl Debug for ChickenVariant
impl Debug for ChickenVariant
impl Eq for ChickenVariant
Sourceimpl PartialEq for ChickenVariant
impl PartialEq for ChickenVariant
Sourceimpl RegistryEntry for ChickenVariant
impl RegistryEntry for ChickenVariant
Sourceimpl RegistryReferenceEntry for ChickenVariant
impl RegistryReferenceEntry for ChickenVariant
Sourceconst REGISTRY_NAME: &'static str = "chicken variant"
const REGISTRY_NAME: &'static str = "chicken variant"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourceimpl ToNbtTag for &ChickenVariant
impl ToNbtTag for &ChickenVariant
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>